<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *********************************************************************************
 * $Header:  \modules\Tooltip\language\hu_hu.lang.php - 12:13 2011.11.12. $
 * Description:  Defines the Hungarian language pack for the Tooltip module vtiger 5.3.x
 *
 * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
 ********************************************************************************/
$mod_strings = array(
	'Tooltip' => 'Súgó',
	'LBL_TOOLTIP_MANAGEMENT' => 'Súgó Beállítások',
	'LBL_TOOLTIP_MANAGEMENT_DESCRIPTION' => 'Itt tudod beállítani a Súgó információkat',
	'LBL_FIELDS_IN' => 'Mezők benne',
	'LBL_TOOLTIP_HELP_TEXT' => 'Válaszd ki azokat a mezőket, amiknek a tartalmát Súgóként meg kívánod jeleníteni',
	'LBL_FIELD' => 'Mező'
);
?>